==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor Federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Zdieľanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať federované zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať federované zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na federované zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať federované zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať federované zdieľania.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Zdieľanie %1$s zlyhalo, pretože táto položka už je užívateľovi %2$s zozdieľaná.",
    "Not allowed to create a federated share to the same account" : "Nie je možné vytvoriť federované zdieľanie so sebou samým",
    "Federated shares require read permissions" : "Federované zdieľanie vyžaduje práva na čítanie",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %1$s s zlyhalo, nepodarilo sa nájsť %2$s, možno je server momentálne nedostupný alebo používa certifikát s vlastným podpisom.",
    "Could not find share" : "Nebolo možné nájsť zdieľanie",
    "Federated sharing" : "Federované zdieľanie",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Federated Cloud Sharing" : "Zdieľanie prostredníctvom federovaného cloudu",
    "Sharing" : "Zdieľanie",
    "Federated file sharing" : "Federované zdieľanie súborov",
    "Provide federated file sharing across servers" : "Poskytnúť združené zdieľanie súborov naprieč servermi",
    "Unable to update federated files sharing config" : "Nedá sa aktualizovať konfigurácia zdieľania združených súborov",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi ľuďmi na tomto serveri ako aj používanie združeného zdieľania.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť užívateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
    "Allow people on this server to receive shares from other servers" : "Povoliť používateľom na tomto serveri prijímať zdieľania z iných serverov",
    "Allow people on this server to send shares to groups on other servers" : "Povoliť užívateľom na tomto serveri odosielať sprístupnenia skupinám na iné servery",
    "Allow people on this server to receive group shares from other servers" : "Povoliť užívateľom na tomto serveri prijímať zdieľania pre skupiny z iných serverov",
    "Search global and public address book for people" : "Vyhľadávať užívateľov v globálnom a verejnom adresári kontaktov",
    "Allow people to publish their data to a global and public address book" : "Povoliť ľuďom publikovanie ich dát do globálneho a verejného adresára.",
    "Trusted federation" : "Dôveryhodná federácia",
    "Automatically accept shares from trusted federated accounts and groups by default" : "V predvolenom nastavení automaticky prijímať zdieľania z dôveryhodných federatívnych účtov a skupín",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Zdieľajte so mnou prostredníctvom môjho #identifikátora združeného cloudu Nextcloud, pozrite {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #identifikátora združeného cloudu Nextcloud",
    "Cloud ID copied to the clipboard" : "Cloud ID bol skopírovaný do schránky",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Clipboard not available. Please copy the cloud ID manually." : "Schránka nie je prístupná. Prosím skopírujte cloud ID manuálne.",
    "Copied!" : "Skopírované!",
    "Federated Cloud" : "Federovaný cloud",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor federovaného cloudu v dialógovom okne zdieľania. Má podobu osoba@cloud.priklad.com",
    "Your Federated Cloud ID" : "Váš identifikátor v rámci federovaného cloudu",
    "Share it so your friends can share files with you:" : "Dajte vedieť vašim priateľom ako s vami môžu zdieľať súbory:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (predtým Twitter)",
    "formerly Twitter" : "predtým Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "HTML Code:" : "HTML kód:",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Remote share" : "Vzdialené úložisko",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Incoming share could not be processed" : "Prichádzajúce zdieľanie sa nepodarilo spracovať",
    "Clipboard is not available" : "Schránka nie je prístupná",
    "Your Federated Cloud ID:" : "Váš identifikátor federovaného cloudu:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Neplatný identifikátor Federovaného cloudu",
    "Server to server sharing is not enabled on this server" : "Zdieľanie server-server nie je na tomto serveri povolené",
    "Couldn't establish a federated share." : "Nepodarilo sa nadviazať federované zdieľanie",
    "Couldn't establish a federated share, maybe the password was wrong." : "Nepodarilo sa nadviazať federované zdieľanie, možno je nesprávne heslo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na federované zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať federované zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať federované zdieľania.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Zdieľanie %1$s zlyhalo, pretože táto položka už je užívateľovi %2$s zozdieľaná.",
    "Not allowed to create a federated share to the same account" : "Nie je možné vytvoriť federované zdieľanie so sebou samým",
    "Federated shares require read permissions" : "Federované zdieľanie vyžaduje práva na čítanie",
    "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %1$s s zlyhalo, nepodarilo sa nájsť %2$s, možno je server momentálne nedostupný alebo používa certifikát s vlastným podpisom.",
    "Could not find share" : "Nebolo možné nájsť zdieľanie",
    "Federated sharing" : "Federované zdieľanie",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Obdržali ste {share} ako vzdialené zdieľanie od {user} (v mene {behalf})",
    "You received {share} as a remote share from {user}" : "Obdržali ste {share} ako vzdialené zdieľanie od {user}",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Federated Cloud Sharing" : "Zdieľanie prostredníctvom federovaného cloudu",
    "Sharing" : "Zdieľanie",
    "Federated file sharing" : "Federované zdieľanie súborov",
    "Provide federated file sharing across servers" : "Poskytnúť združené zdieľanie súborov naprieč servermi",
    "Confirm data upload to lookup server" : "Potvrdiť nahranie dáť na vyhľadávací server",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Keď je táto možnosť povolená, všetky vlastnosti účtu (napr. e-mailová adresa) s viditeľnosťou rozsahu nastavenou na „zverejnené“ sa automaticky synchronizujú a prenesú do externého systému a sprístupnia sa vo verejnom globálnom adresári.",
    "Disable upload" : "Zakázať nahrávanie",
    "Enable data upload" : "Povoliť nahrávanie dát",
    "Confirm querying lookup server" : "Potvrďte dotaz na vyhľadávací server",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Keď je táto možnosť povolená, vyhľadávací vstup pri vytváraní zdieľaných položiek sa odošle do externého systému, ktorý poskytuje verejný a globálny adresár.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Používa sa na získanie federatívneho cloudového ID, aby sa uľahčilo federatívne zdieľanie.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Okrem toho môžu byť do tohto systému odoslané e-mailové adresy užívateľov, aby sa mohli overiť.",
    "Disable querying" : "Zakázať dotazovanie",
    "Enable querying" : "Povoliť dotazovanie",
    "Unable to update federated files sharing config" : "Nedá sa aktualizovať konfigurácia zdieľania združených súborov",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi ľuďmi na tomto serveri ako aj používanie združeného zdieľania.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť užívateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
    "Allow people on this server to receive shares from other servers" : "Povoliť používateľom na tomto serveri prijímať zdieľania z iných serverov",
    "Allow people on this server to send shares to groups on other servers" : "Povoliť užívateľom na tomto serveri odosielať sprístupnenia skupinám na iné servery",
    "Allow people on this server to receive group shares from other servers" : "Povoliť užívateľom na tomto serveri prijímať zdieľania pre skupiny z iných serverov",
    "The lookup server is only available for global scale." : "Vyhľadávací server je dostupný len v globálnej škále.",
    "Search global and public address book for people" : "Vyhľadávať užívateľov v globálnom a verejnom adresári kontaktov",
    "Allow people to publish their data to a global and public address book" : "Povoliť ľuďom publikovanie ich dát do globálneho a verejného adresára.",
    "Trusted federation" : "Dôveryhodná federácia",
    "Automatically accept shares from trusted federated accounts and groups by default" : "V predvolenom nastavení automaticky prijímať zdieľania z dôveryhodných federatívnych účtov a skupín",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Zdieľajte so mnou prostredníctvom môjho #identifikátora združeného cloudu Nextcloud, pozrite {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Sprístupnite mi obsah prostredníctvom môjho #identifikátora združeného cloudu Nextcloud",
    "Share with me via Nextcloud" : "Sprístupnené cez Nextcloud",
    "Copy" : "Kopírovať",
    "Clipboard not available. Please copy the cloud ID manually." : "Schránka nie je prístupná. Prosím skopírujte cloud ID manuálne.",
    "Copied!" : "Skopírované!",
    "Federated Cloud" : "Federovaný cloud",
    "Your Federated Cloud ID" : "Váš identifikátor v rámci federovaného cloudu",
    "Share it so your friends can share files with you:" : "Dajte vedieť vašim priateľom ako s vami môžu zdieľať súbory:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (predtým Twitter)",
    "formerly Twitter" : "predtým Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Pridať na svoju webstránku",
    "HTML Code:" : "HTML kód:",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "Remote share" : "Vzdialené úložisko",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Incoming share could not be processed" : "Prichádzajúce zdieľanie sa nepodarilo spracovať",
    "Cloud ID copied to the clipboard" : "Cloud ID bol skopírovaný do schránky",
    "Copy to clipboard" : "Skopírovať do schránky",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor federovaného cloudu v dialógovom okne zdieľania. Má podobu osoba@cloud.priklad.com"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
